pub struct CreateMint {
pub mint: Pubkey,
pub mint_authority: Pubkey,
pub payer: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for CreateMint.
Fields
mint: Pubkeypayer: Pubkeytoken_program: Pubkeysystem_program: Pubkeyrent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateMintwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateMintwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateMint
impl ToAccountMetas for CreateMint
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateMint
impl RefUnwindSafe for CreateMint
impl Send for CreateMint
impl Sync for CreateMint
impl Unpin for CreateMint
impl UnwindSafe for CreateMint